==> diffie_hellman-1.1.1.tar.gz: test/src/keys/codec/dh_public_key_codec_test.dart <==
import 'package:diffie_hellman/src/keys/codec/dh_public_key_codec.dart';
import 'package:diffie_hellman/src/keys/dh_public_key.dart';
import 'package:diffie_hellman/src/spec/dh_parameter.dart';
import 'package:test/test.dart';

void main() {
  DhPublicKeyCodec codec = DhPublicKeyCodec();
  test('Test getters', () {
    expect(codec.beginDelimiter, '-----BEGIN PUBLIC KEY-----');
    expect(codec.endDelimiter, '-----END PUBLIC KEY-----');
  });
  group('Test decode', () {
    test('success', () {
      String pem = '-----BEGIN PUBLIC KEY-----'
          'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
          'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
          'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
          '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
          'aHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
          'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
          'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
          'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
          '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
          'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
          'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
          '-----END PUBLIC KEY-----';

      DhPublicKey key = codec.decode(pem);

      expect(key, isA<DhPublicKey>());
      expect(
        key.value,
        BigInt.parse(
          '13597176220580919649527592465557439085416476870532439476349241521813'
          '2137335032858050255079076586066790482780869079764149599664888068'
          '4923268009611134191700863659977305550271483788023152614106143025'
          '0382065802586073613213839530904903899116992892465945546318611711'
          '5056100932687003962160107577945710699659407925661019164707397721'
          '8193964285986875185181061756070128674460481773821692432493868672'
          '5081077677515502299407133412916861967143112500185157843876695943'
          '8060861623344312246231172420661292752988037127377914691449943320'
          '4048774992724970269959760356171809516743532723894173480781887459'
          '957835946902018680242020305779282349273035389',
        ),
      );
      expect(key.parameter.g, 2);
      expect(
        key.parameter.length,
        isNull,
      );
      expect(
        key.parameter.p,
        BigInt.parse(
          '1705981236470358725694168947912340905184016456649447827905035366'
          '423517535309908785587707055879384617579501090023314190176825'
          '906194053926198680818787330824514093789425038991297310899347'
          '879603007390591295367927989200428479181392167186038274353771'
          '051467944239198579360702639880632257276543722599876705523832'
          '383110847754263857714814930133028553636527166334698763092635'
          '309746869886837672874917937355659269162487244401397961380983'
          '492065819046040513532179748873242190063094003226840334898050'
          '065909470313763757295606726586211667148768695097521928028357'
          '150201410623989347868579314525119658923402674799093063288032'
          '9238408161847',
        ),
      );
      expect(key.parameter.p.bitLength, 2048);
    });
    test('error', () {
      String pem = '-----BEGIN PUBLIC KEY-----'
          'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
          'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
          'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
          '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
          'aHDLO3xptDI3g/rD4dFmAvsdfdsfdse60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
          'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
          'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
          'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
          '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
          'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
          'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
          '-----END PUBLIC KEY-----';

      expect(
        () => codec.decode(pem),
        throwsA(isA<ArgumentError>()),
      );
    });
  });

  group('Test encode', () {
    test('success', () {
      DhPublicKey privateKey = DhPublicKey(
        BigInt.parse(
          '13597176220580919649527592465557439085416476870532439476349241521813'
          '2137335032858050255079076586066790482780869079764149599664888068'
          '4923268009611134191700863659977305550271483788023152614106143025'
          '0382065802586073613213839530904903899116992892465945546318611711'
          '5056100932687003962160107577945710699659407925661019164707397721'
          '8193964285986875185181061756070128674460481773821692432493868672'
          '5081077677515502299407133412916861967143112500185157843876695943'
          '8060861623344312246231172420661292752988037127377914691449943320'
          '4048774992724970269959760356171809516743532723894173480781887459'
          '957835946902018680242020305779282349273035389',
        ),
        parameter: DhParameter(
          g: 2,
          p: BigInt.parse(
            '1705981236470358725694168947912340905184016456649447827905035366'
            '423517535309908785587707055879384617579501090023314190176825'
            '906194053926198680818787330824514093789425038991297310899347'
            '879603007390591295367927989200428479181392167186038274353771'
            '051467944239198579360702639880632257276543722599876705523832'
            '383110847754263857714814930133028553636527166334698763092635'
            '309746869886837672874917937355659269162487244401397961380983'
            '492065819046040513532179748873242190063094003226840334898050'
            '065909470313763757295606726586211667148768695097521928028357'
            '150201410623989347868579314525119658923402674799093063288032'
            '9238408161847',
          ),
        ),
      );

      String pem = codec.encode(privateKey);

      expect(
        pem,
        '-----BEGIN PUBLIC KEY-----'
        'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
        'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
        'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
        '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
        'aHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
        'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
        'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
        'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
        '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
        'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
        'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
        '-----END PUBLIC KEY-----',
      );
    });
  });
}

==> diffie_hellman-1.1.4.tar.gz: test/src/keys/codec/dh_public_key_codec_test.dart <==
import 'package:diffie_hellman/src/keys/codec/dh_public_key_codec.dart';
import 'package:diffie_hellman/src/keys/dh_public_key.dart';
import 'package:diffie_hellman/src/spec/dh_parameter.dart';
import 'package:test/test.dart';

void main() {
  DhPublicKeyCodec codec = DhPublicKeyCodec();
  test('Test getters', () {
    expect(codec.beginDelimiter, '-----BEGIN PUBLIC KEY-----');
    expect(codec.endDelimiter, '-----END PUBLIC KEY-----');
  });
  group('Test decode', () {
    test('success', () {
      String pem = '-----BEGIN PUBLIC KEY-----'
          'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
          'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
          'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
          '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
          'aHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
          'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
          'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
          'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
          '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
          'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
          'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
          '-----END PUBLIC KEY-----';

      DhPublicKey key = codec.decode(pem);

      expect(key, isA<DhPublicKey>());
      expect(
        key.value,
        BigInt.parse(
          '13597176220580919649527592465557439085416476870532439476349241521813'
          '2137335032858050255079076586066790482780869079764149599664888068'
          '4923268009611134191700863659977305550271483788023152614106143025'
          '0382065802586073613213839530904903899116992892465945546318611711'
          '5056100932687003962160107577945710699659407925661019164707397721'
          '8193964285986875185181061756070128674460481773821692432493868672'
          '5081077677515502299407133412916861967143112500185157843876695943'
          '8060861623344312246231172420661292752988037127377914691449943320'
          '4048774992724970269959760356171809516743532723894173480781887459'
          '957835946902018680242020305779282349273035389',
        ),
      );
      expect(key.parameter.g, BigInt.two);
      expect(
        key.parameter.l,
        isNull,
      );
      expect(
        key.parameter.p,
        BigInt.parse(
          '1705981236470358725694168947912340905184016456649447827905035366'
          '423517535309908785587707055879384617579501090023314190176825'
          '906194053926198680818787330824514093789425038991297310899347'
          '879603007390591295367927989200428479181392167186038274353771'
          '051467944239198579360702639880632257276543722599876705523832'
          '383110847754263857714814930133028553636527166334698763092635'
          '309746869886837672874917937355659269162487244401397961380983'
          '492065819046040513532179748873242190063094003226840334898050'
          '065909470313763757295606726586211667148768695097521928028357'
          '150201410623989347868579314525119658923402674799093063288032'
          '9238408161847',
        ),
      );
      expect(key.parameter.p.bitLength, 2048);
    });
    test('error', () {
      String pem = '-----BEGIN PUBLIC KEY-----'
          'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
          'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
          'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
          '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
          'aHDLO3xptDI3g/rD4dFmAvsdfdsfdse60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
          'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
          'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
          'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
          '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
          'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
          'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
          '-----END PUBLIC KEY-----';

      expect(
        () => codec.decode(pem),
        throwsA(isA<ArgumentError>()),
      );
    });
  });

  group('Test encode', () {
    test('success', () {
      DhPublicKey privateKey = DhPublicKey(
        BigInt.parse(
          '13597176220580919649527592465557439085416476870532439476349241521813'
          '2137335032858050255079076586066790482780869079764149599664888068'
          '4923268009611134191700863659977305550271483788023152614106143025'
          '0382065802586073613213839530904903899116992892465945546318611711'
          '5056100932687003962160107577945710699659407925661019164707397721'
          '8193964285986875185181061756070128674460481773821692432493868672'
          '5081077677515502299407133412916861967143112500185157843876695943'
          '8060861623344312246231172420661292752988037127377914691449943320'
          '4048774992724970269959760356171809516743532723894173480781887459'
          '957835946902018680242020305779282349273035389',
        ),
        parameter: DhParameter(
          g: BigInt.two,
          p: BigInt.parse(
            '1705981236470358725694168947912340905184016456649447827905035366'
            '423517535309908785587707055879384617579501090023314190176825'
            '906194053926198680818787330824514093789425038991297310899347'
            '879603007390591295367927989200428479181392167186038274353771'
            '051467944239198579360702639880632257276543722599876705523832'
            '383110847754263857714814930133028553636527166334698763092635'
            '309746869886837672874917937355659269162487244401397961380983'
            '492065819046040513532179748873242190063094003226840334898050'
            '065909470313763757295606726586211667148768695097521928028357'
            '150201410623989347868579314525119658923402674799093063288032'
            '9238408161847',
          ),
        ),
      );

      String pem = codec.encode(privateKey);

      expect(
        pem,
        '-----BEGIN PUBLIC KEY-----'
        'MIICJDCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ58Lf'
        'KITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I80EK'
        'xopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7'
        '/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLB'
        'aHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/'
        'n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIDggEFAAKCAQB+ZF2EgwIZWZkd'
        'RDzrIv3lRlBg/v1AYaYytjDzeL6G3NxvcB9uXBtsHJu9E9K0TRs2B0zYCX1v9yhAwM9r'
        'YGOqnjflqAVMhodtjLURCvamslEbnoCg3Gm8uYPu6KkTvDpjPGedKOjQNWAgJQREi1Wv'
        '+ZgTSR4TnzIFmPsxaWgifIV9Eo+mnHtMk9BynX5c4eh3FUwSAcilT4UbMHHDzNwYDda3'
        'gu3CQKDun+nF3nFYWg1iRZHr/6pjOgngIMPX4YSzpezbk3EXGe2qYKDBOxWoepIHnWt3'
        'e+8gWxPdyXB6oB3P/7+xrIXw4myJ0I2o8j78sq4hKXA0LQq1y2m8yrJ9'
        '-----END PUBLIC KEY-----',
      );
    });
  });
}
